@@ -10,45 +10,45 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.19';
+$VERSION = '0.20';
 $DATE = '2004/05/23';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.19 2004/05/23), 'revised 0.18'],
-    'MANIFEST' => [qw(0.19 2004/05/23), 'generated, replaces 0.18'],
-    'Makefile.PL' => [qw(0.19 2004/05/23), 'generated, replaces 0.18'],
-    'README' => [qw(0.19 2004/05/23), 'generated, replaces 0.18'],
+    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.20 2004/05/23), 'revised 0.19'],
+    'MANIFEST' => [qw(0.20 2004/05/23), 'generated, replaces 0.19'],
+    'Makefile.PL' => [qw(0.20 2004/05/23), 'generated, replaces 0.19'],
+    'README' => [qw(0.20 2004/05/23), 'generated, replaces 0.19'],
     'lib/Test/STDmaker.pm' => [qw(1.19 2004/05/22), 'unchanged'],
-    'lib/Test/STDmaker/Check.pm' => [qw(1.14 2004/05/22), 'unchanged'],
+    'lib/Test/STDmaker/Check.pm' => [qw(1.15 2004/05/23), 'revised 1.14'],
     'lib/Test/STDmaker/Demo.pm' => [qw(1.14 2004/05/21), 'unchanged'],
-    'lib/Test/STDmaker/STD.pm' => [qw(1.11 2004/05/21), 'unchanged'],
+    'lib/Test/STDmaker/STD.pm' => [qw(1.12 2004/05/23), 'revised 1.11'],
     'lib/Test/STDmaker/Verify.pm' => [qw(1.15 2004/05/22), 'unchanged'],
     'lib/Test/STD/PerlSTD.pm' => [qw(1.08 2004/05/19), 'unchanged'],
-    't/Test/STDmaker/STDmaker.d' => [qw(0.16 2004/05/23), 'revised 0.15'],
-    't/Test/STDmaker/STDmaker.pm' => [qw(0.14 2004/05/23), 'revised 0.13'],
-    't/Test/STDmaker/STDmaker.t' => [qw(0.16 2004/05/23), 'revised 0.15'],
+    't/Test/STDmaker/STDmaker.d' => [qw(0.17 2004/05/23), 'revised 0.16'],
+    't/Test/STDmaker/STDmaker.pm' => [qw(0.15 2004/05/23), 'revised 0.14'],
+    't/Test/STDmaker/STDmaker.t' => [qw(0.17 2004/05/23), 'revised 0.16'],
     't/Test/STDmaker/tg0.pm' => [qw(0.03 2004/04/09), 'unchanged'],
-    't/Test/STDmaker/tg2A.pm' => [qw(0.03 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tg2B.pm' => [qw(0.03 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgA0.pm' => [qw(0.06 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgA1.pm' => [qw(0.06 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgA2.pm' => [qw(0.01 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgA2A2.txt' => [qw(0.12 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgA2A3.txt' => [qw(0.12 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tg2A.pm' => [qw(0.06 2004/05/23), 'revised 0.05'],
+    't/Test/STDmaker/tg2B.pm' => [qw(0.07 2004/05/23), 'revised 0.06'],
+    't/Test/STDmaker/tgA0.pm' => [qw(0.08 2004/05/23), 'revised 0.07'],
+    't/Test/STDmaker/tgA1.pm' => [qw(0.08 2004/05/23), 'revised 0.07'],
+    't/Test/STDmaker/tgA2.pm' => [qw(0.09 2004/05/23), 'revised 0.08'],
+    't/Test/STDmaker/tgA2A2.txt' => [qw(0.13 2004/05/23), 'revised 0.12'],
+    't/Test/STDmaker/tgA2A3.txt' => [qw(0.13 2004/05/23), 'revised 0.12'],
     't/Test/STDmaker/tgA2B.txt' => [qw(0.09 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tgA2C.txt' => [qw(0.1 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tgB0.pm' => [qw(0.02 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgB1.pm' => [qw(0.01 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgB2.pm' => [qw(0.03 2004/05/21), 'unchanged'],
-    't/Test/STDmaker/tgB2.txt' => [qw(0.09 2004/05/14), 'unchanged'],
+    't/Test/STDmaker/tgB1.pm' => [qw(0.02 2004/05/23), 'revised 0.01'],
+    't/Test/STDmaker/tgB2.pm' => [qw(0.04 2004/05/23), 'revised 0.03'],
+    't/Test/STDmaker/tgB2.txt' => [qw(0.1 2004/05/23), 'revised 0.09'],
     't/Test/STDmaker/tgC0.pm' => [qw(0.04 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgC1.pm' => [qw(0.01 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/tgC2.pm' => [qw(0.05 2004/05/21), 'unchanged'],
+    't/Test/STDmaker/tgC1.pm' => [qw(0.02 2004/05/23), 'revised 0.01'],
+    't/Test/STDmaker/tgC2.pm' => [qw(0.06 2004/05/23), 'revised 0.05'],
     't/Test/STDmaker/tgD0.pm' => [qw(0.06 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tmake.pl' => [qw(1.06 2004/05/23), 'unchanged'],
-    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.14 2004/05/23), 'unchanged'],
+    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.15 2004/05/23), 'revised 1.14'],
     't/Test/STDmaker/Test/Tech.pm' => [qw(1.26 2004/05/23), 'unchanged'],
     't/Test/STDmaker/Data/Secs2.pm' => [qw(1.26 2004/05/23), 'unchanged'],
     't/Test/STDmaker/Data/Str2Num.pm' => [qw(0.08 2004/05/23), 'unchanged'],
@@ -83,9 +83,9 @@ Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test
 
  Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test description short hand
 
- Revision: Q
+ Revision: R
 
- Version: 0.19
+ Version: 0.20
 
  Date: 2004/05/23
 
@@ -176,7 +176,7 @@ further detail on the text database fields and the processing.
 
 =head2 1.3 Document overview.
 
-This document releases Test::STDmaker version 0.19
+This document releases Test::STDmaker version 0.20
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -191,7 +191,7 @@ system file specification.
 
 This document releases the file 
 
- Test-STDmaker-0.19.tar.gz
+ Test-STDmaker-0.20.tar.gz
 
 found at the following repository(s):
 
@@ -278,39 +278,39 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_STDmaker.pm                           0.19    2004/05/23 revised 0.18
- MANIFEST                                                     0.19    2004/05/23 generated, replaces 0.18
- Makefile.PL                                                  0.19    2004/05/23 generated, replaces 0.18
- README                                                       0.19    2004/05/23 generated, replaces 0.18
+ lib/Docs/Site_SVD/Test_STDmaker.pm                           0.20    2004/05/23 revised 0.19
+ MANIFEST                                                     0.20    2004/05/23 generated, replaces 0.19
+ Makefile.PL                                                  0.20    2004/05/23 generated, replaces 0.19
+ README                                                       0.20    2004/05/23 generated, replaces 0.19
  lib/Test/STDmaker.pm                                         1.19    2004/05/22 unchanged
- lib/Test/STDmaker/Check.pm                                   1.14    2004/05/22 unchanged
+ lib/Test/STDmaker/Check.pm                                   1.15    2004/05/23 revised 1.14
  lib/Test/STDmaker/Demo.pm                                    1.14    2004/05/21 unchanged
- lib/Test/STDmaker/STD.pm                                     1.11    2004/05/21 unchanged
+ lib/Test/STDmaker/STD.pm                                     1.12    2004/05/23 revised 1.11
  lib/Test/STDmaker/Verify.pm                                  1.15    2004/05/22 unchanged
  lib/Test/STD/PerlSTD.pm                                      1.08    2004/05/19 unchanged
- t/Test/STDmaker/STDmaker.d                                   0.16    2004/05/23 revised 0.15
- t/Test/STDmaker/STDmaker.pm                                  0.14    2004/05/23 revised 0.13
- t/Test/STDmaker/STDmaker.t                                   0.16    2004/05/23 revised 0.15
+ t/Test/STDmaker/STDmaker.d                                   0.17    2004/05/23 revised 0.16
+ t/Test/STDmaker/STDmaker.pm                                  0.15    2004/05/23 revised 0.14
+ t/Test/STDmaker/STDmaker.t                                   0.17    2004/05/23 revised 0.16
  t/Test/STDmaker/tg0.pm                                       0.03    2004/04/09 unchanged
- t/Test/STDmaker/tg2A.pm                                      0.03    2004/05/22 unchanged
- t/Test/STDmaker/tg2B.pm                                      0.03    2004/05/22 unchanged
- t/Test/STDmaker/tgA0.pm                                      0.06    2004/05/22 unchanged
- t/Test/STDmaker/tgA1.pm                                      0.06    2004/05/22 unchanged
- t/Test/STDmaker/tgA2.pm                                      0.01    2004/05/22 unchanged
- t/Test/STDmaker/tgA2A2.txt                                   0.12    2004/05/22 unchanged
- t/Test/STDmaker/tgA2A3.txt                                   0.12    2004/05/22 unchanged
+ t/Test/STDmaker/tg2A.pm                                      0.06    2004/05/23 revised 0.05
+ t/Test/STDmaker/tg2B.pm                                      0.07    2004/05/23 revised 0.06
+ t/Test/STDmaker/tgA0.pm                                      0.08    2004/05/23 revised 0.07
+ t/Test/STDmaker/tgA1.pm                                      0.08    2004/05/23 revised 0.07
+ t/Test/STDmaker/tgA2.pm                                      0.09    2004/05/23 revised 0.08
+ t/Test/STDmaker/tgA2A2.txt                                   0.13    2004/05/23 revised 0.12
+ t/Test/STDmaker/tgA2A3.txt                                   0.13    2004/05/23 revised 0.12
  t/Test/STDmaker/tgA2B.txt                                    0.09    2004/05/22 unchanged
  t/Test/STDmaker/tgA2C.txt                                    0.1     2004/05/22 unchanged
  t/Test/STDmaker/tgB0.pm                                      0.02    2004/05/18 unchanged
- t/Test/STDmaker/tgB1.pm                                      0.01    2004/05/22 unchanged
- t/Test/STDmaker/tgB2.pm                                      0.03    2004/05/21 unchanged
- t/Test/STDmaker/tgB2.txt                                     0.09    2004/05/14 unchanged
+ t/Test/STDmaker/tgB1.pm                                      0.02    2004/05/23 revised 0.01
+ t/Test/STDmaker/tgB2.pm                                      0.04    2004/05/23 revised 0.03
+ t/Test/STDmaker/tgB2.txt                                     0.1     2004/05/23 revised 0.09
  t/Test/STDmaker/tgC0.pm                                      0.04    2004/05/18 unchanged
- t/Test/STDmaker/tgC1.pm                                      0.01    2004/05/22 unchanged
- t/Test/STDmaker/tgC2.pm                                      0.05    2004/05/21 unchanged
+ t/Test/STDmaker/tgC1.pm                                      0.02    2004/05/23 revised 0.01
+ t/Test/STDmaker/tgC2.pm                                      0.06    2004/05/23 revised 0.05
  t/Test/STDmaker/tgD0.pm                                      0.06    2004/05/22 unchanged
  t/Test/STDmaker/tmake.pl                                     1.06    2004/05/23 unchanged
- t/Test/STDmaker/Text/Scrub.pm                                1.14    2004/05/23 unchanged
+ t/Test/STDmaker/Text/Scrub.pm                                1.15    2004/05/23 revised 1.14
  t/Test/STDmaker/Test/Tech.pm                                 1.26    2004/05/23 unchanged
  t/Test/STDmaker/Data/Secs2.pm                                1.26    2004/05/23 unchanged
  t/Test/STDmaker/Data/Str2Num.pm                              0.08    2004/05/23 unchanged
@@ -571,7 +571,7 @@ Analysis:
 The text begin picked up in method comes from C<Test::STDmaker::STD.pm> 
 
  # Don't edit anything before __DATA_. Edit instead
- 
+
 within a <<'EOF' here statement.
 
 Corrective Action:
@@ -653,6 +653,45 @@ Debug:
 Put in warns to take look at generated files. So remotely debugging with print 
 statement.
 
+=item Test-STDmaker-0.20
+
+Test Failure:
+
+ Subject: FAIL Test-STDmaker-0.19 ppc-linux 2.4.19-4a 
+ From: alian@cpan.org (CPAN Tester + CPAN++ automate) 
+
+ t/Test/STDmaker/STDmaker....######
+ ok: 9
+ ~~~~~~~
+ tgA1.pm
+ [snip]
+
+ __DATA__
+
+ [snip]
+
+ T: 22 - 3,6,14,17^
+
+ [snip]
+
+Analysis:
+
+Still in debug, investigate mode. 
+Second time access __DATA__ in tgA1.pm, the data gets doubled.
+This problem usually caused by lack of initialization. However, after steppng through
+a couple of times looked good. Suspect that reading database from the __DATA__ section
+twice may be the problem. 
+Need to add a test with File::Maker and run it on these sites that are failing
+to see if this is the problem.
+
+Also do not understand yet why test 10 that compares tgA1.pm against expected tgA2.pm
+does not fail. Simulation under Windows and stepping thru with debugger provides a 
+failure.
+
+Debug:
+
+Add internal variables to $diag and put them in the warn for ok 9.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -691,13 +730,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Test-STDmaker-0.19.tar.gz' and download to a temporary
+Right click on 'Test-STDmaker-0.20.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Test-STDmaker-0.19.tar.gz
- tar -xf Test-STDmaker-0.19.tar
+ gunzip Test-STDmaker-0.20.tar.gz
+ tar -xf Test-STDmaker-0.20.tar
  perl Makefile.PL
  $make test
  $make install
@@ -839,10 +878,10 @@ __DATA__
 DISTNAME: Test-STDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.19^
+VERSION : 0.20^
 FREEZE: 1^
-PREVIOUS_RELEASE: 0.18^
-REVISION: Q^
+PREVIOUS_RELEASE: 0.19^
+REVISION: R^
 
 PREVIOUS_DISTNAME:  ^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -1220,7 +1259,7 @@ Analysis:
 The text begin picked up in method comes from C<Test::STDmaker::STD.pm> 
 
  # Don't edit anything before __DATA_. Edit instead
- 
+
 within a <<'EOF' here statement.
 
 Corrective Action:
@@ -1302,6 +1341,45 @@ Debug:
 Put in warns to take look at generated files. So remotely debugging with print 
 statement.
 
+\=item Test-STDmaker-0.20
+
+Test Failure:
+
+ Subject: FAIL Test-STDmaker-0.19 ppc-linux 2.4.19-4a 
+ From: alian@cpan.org (CPAN Tester + CPAN++ automate) 
+
+ t/Test/STDmaker/STDmaker....######
+ ok: 9
+ ~~~~~~~
+ tgA1.pm
+ [snip]
+
+ __DATA__
+
+ [snip]
+
+ T: 22 - 3,6,14,17^^
+
+ [snip]
+
+Analysis:
+
+Still in debug, investigate mode. 
+Second time access __DATA__ in tgA1.pm, the data gets doubled.
+This problem usually caused by lack of initialization. However, after steppng through
+a couple of times looked good. Suspect that reading database from the __DATA__ section
+twice may be the problem. 
+Need to add a test with File::Maker and run it on these sites that are failing
+to see if this is the problem.
+
+Also do not understand yet why test 10 that compares tgA1.pm against expected tgA2.pm
+does not fail. Simulation under Windows and stepping thru with debugger provides a 
+failure.
+
+Debug:
+
+Add internal variables to $diag and put them in the warn for ok 9.
+
 \=back
 
 ^
@@ -1548,6 +1626,14 @@ HTML: ^
 
 
 
+
+
+
+
+
+
+
+
 
 
 
